@@ -5,7 +5,10 @@
 #'   Otherwise, defaults to NULL and will return an xml_document object.
 #' @param root name for the root node; default to 'eml'
 #' @param ns namespace abbreviation on root node, default 'eml'
-#' @param schemaLocation default to set schemaLocation if not already defined in emld object
+#' @param schemaLocation If not explicitly set on `x`, automatically set
+#' `xsi:schemaLocation` based upon the root namespace (`TRUE`, default), do not
+#' set a `xsi:schemaLocation` (`FALSE`), or set a specific `xsi:schemaLocation`
+#' value (`"Your value here..."`). See Examples.
 #' @export
 #' @details Unlike as_json, this function cannot rely on the existing
 #' convention of serializing a list to xml, eg, as defined by xml2::as_xml_document()
@@ -22,24 +25,32 @@
 #' ## can also write directly to a file:
 #' xml_file <- tempfile()
 #' as_xml(emld, xml_file)
+#'
+#' ## if you don't want the `xsi:schemaLocation` attribute set
+#' as_xml(emld, schemaLocation = FALSE)
+#'
+#' ## or if you want to set your own value
+#' as_xml(emld, schemaLocation = "https://eml.ecoinformatics.org/eml-2.2.0
+#' http://example.com/eml-2.2.0/eml.xsd")
+#'
 #' @return a xml_document object. Or if a file path is provided, the metadata
 #' is written out in XML file and the function returns `NULL` invisibly.
 as_xml <- function(x, file=NULL, root = "eml", ns = "eml",
-  schemaLocation = paste0(eml_ns(), "/ eml.xsd"))
+  schemaLocation = TRUE)
   {
     UseMethod("as_xml")
   }
 
 #' @export
 as_xml.list <- function(x, file=NULL, root = "eml", ns = "eml",
-                        schemaLocation = paste0(eml_ns(), "/ eml.xsd")){
+                        schemaLocation = TRUE){
   x <- as_emld.list(x)
   as_xml.emld(x, file)
 }
 
 #' @export
 as_xml.emld <- function(x, file=NULL, root = "eml", ns = "eml",
-                        schemaLocation = paste0(eml_ns(), "/ eml.xsd")){
+                        schemaLocation = TRUE){
   ## Frame/compact into original context for a standardized structure
   x <- eml_frame(x)
 
@@ -50,11 +61,23 @@ as_xml.emld <- function(x, file=NULL, root = "eml", ns = "eml",
   x[["@context"]] <- NULL
   x[["@type"]] <- NULL
 
-  ## add schemaLocation
-  if(is.null(x[["schemaLocation"]])){
-    if(!is.null(schemaLocation))
-    x[["schemaLocation"]] <- schemaLocation
+  ## handle schemaLocation
+  if (!is.null(x[["schemaLocation"]]) && isFALSE(schemaLocation)) {
+    message("A value for 'schemaLocation' was set in the document but the",
+            " 'schemaLocation' argument was set to 'FALSE' so the value from",
+            " the document was retained. To serialize a document without a",
+            " schemaLocation, remove the 'schemaLocation' element from the",
+            " document before serializing.")
   }
+
+  if (is.null(x[["schemaLocation"]])) {
+    if (isTRUE(schemaLocation)) {
+      x[["schemaLocation"]] <- guess_schema_location()
+    } else if (is.character(schemaLocation)) {
+      x[["schemaLocation"]] <- schemaLocation
+    }
+  }
+
   ## here we go, serialize to XML!
   xml <- as_eml_document(x, root = root, ns = ns)
 
